"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2
import yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SynchronizationServiceStub:
    """A set of methods for managing synchronization settings."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    SetReplicationToken: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the replication token for synchronization."""

    ResetReplicationToken: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resets the replication token for synchronization."""

    CreateSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates synchronization settings for a subject container."""

    UpdateSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates synchronization settings for a subject container."""

    DeleteSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes synchronization settings for a subject container."""

    GetSynchronizationSettings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings,
    ]
    """Returns synchronization settings for a subject container."""

    ListSupportedAttributes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse,
    ]
    """Lists supported attributes for synchronization."""

class SynchronizationServiceAsyncStub:
    """A set of methods for managing synchronization settings."""

    SetReplicationToken: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the replication token for synchronization."""

    ResetReplicationToken: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Resets the replication token for synchronization."""

    CreateSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates synchronization settings for a subject container."""

    UpdateSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates synchronization settings for a subject container."""

    DeleteSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes synchronization settings for a subject container."""

    GetSynchronizationSettings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings,
    ]
    """Returns synchronization settings for a subject container."""

    ListSupportedAttributes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse,
    ]
    """Lists supported attributes for synchronization."""

class SynchronizationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing synchronization settings."""

    @abc.abstractmethod
    def SetReplicationToken(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.SetReplicationTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the replication token for synchronization."""

    @abc.abstractmethod
    def ResetReplicationToken(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ResetReplicationTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Resets the replication token for synchronization."""

    @abc.abstractmethod
    def CreateSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.CreateSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates synchronization settings for a subject container."""

    @abc.abstractmethod
    def UpdateSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.UpdateSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates synchronization settings for a subject container."""

    @abc.abstractmethod
    def DeleteSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.DeleteSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes synchronization settings for a subject container."""

    @abc.abstractmethod
    def GetSynchronizationSettings(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.GetSynchronizationSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings]]:
        """Returns synchronization settings for a subject container."""

    @abc.abstractmethod
    def ListSupportedAttributes(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.synchronization_service_pb2.ListSupportedAttributesResponse]]:
        """Lists supported attributes for synchronization."""

def add_SynchronizationServiceServicer_to_server(servicer: SynchronizationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKyandex/cloud/organizationmanager/v1/idp/application/oauth/application.proto\x12\x39yandex.cloud.organizationmanager.v1.idp.application.oauth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe8\x04\n\x0b\x41pplication\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12m\n\x15group_claims_settings\x18\x05 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.oauth.GroupClaimsSettings\x12\\\n\x0c\x63lient_grant\x18\x06 \x01(\x0b\x32\x46.yandex.cloud.organizationmanager.v1.idp.application.oauth.ClientGrant\x12Q\n\x06status\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.organizationmanager.v1.idp.application.oauth.Status\x12\x62\n\x06labels\x18\x08 \x03(\x0b\x32R.yandex.cloud.organizationmanager.v1.idp.application.oauth.Application.LabelsEntry\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x13GroupClaimsSettings\x12q\n\x17group_distribution_type\x18\x01 \x01(\x0e\x32P.yandex.cloud.organizationmanager.v1.idp.application.oauth.GroupDistributionType\"^\n\x0b\x43lientGrant\x12\x1f\n\tclient_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x11\x61uthorized_scopes\x18\x02 \x03(\tB\x13\x82\xc8\x31\x06\x31-1000\x8a\xc8\x31\x05<=255*W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04*o\n\x15GroupDistributionType\x12\'\n#GROUP_DISTRIBUTION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x13\n\x0f\x41SSIGNED_GROUPS\x10\x02\x12\x0e\n\nALL_GROUPS\x10\x03\x42\xa4\x01\n=yandex.cloud.api.organizationmanager.v1.idp.application.oauthZcgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/oauth;oauthb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n=yandex.cloud.api.organizationmanager.v1.idp.application.oauthZcgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/oauth;oauth'
  _globals['_APPLICATION_LABELSENTRY']._loaded_options = None
  _globals['_APPLICATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLIENTGRANT'].fields_by_name['client_id']._loaded_options = None
  _globals['_CLIENTGRANT'].fields_by_name['client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLIENTGRANT'].fields_by_name['authorized_scopes']._loaded_options = None
  _globals['_CLIENTGRANT'].fields_by_name['authorized_scopes']._serialized_options = b'\202\3101\0061-1000\212\3101\005<=255'
  _globals['_STATUS']._serialized_start=1056
  _globals['_STATUS']._serialized_end=1143
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_start=1145
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_end=1256
  _globals['_APPLICATION']._serialized_start=203
  _globals['_APPLICATION']._serialized_end=819
  _globals['_APPLICATION_LABELSENTRY']._serialized_start=774
  _globals['_APPLICATION_LABELSENTRY']._serialized_end=819
  _globals['_GROUPCLAIMSSETTINGS']._serialized_start=822
  _globals['_GROUPCLAIMSSETTINGS']._serialized_end=958
  _globals['_CLIENTGRANT']._serialized_start=960
  _globals['_CLIENTGRANT']._serialized_end=1054
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/metadata_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/metadata_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/billing/usage_records/v1/metadata_service.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x1dyandex/cloud/validation.proto\"\x9d\x01\n\x0fGetUsageRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\"\xb1\x02\n\x10GetUsageResponse\x12<\n\x06\x63louds\x18\x01 \x03(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12\x12\n\nlabel_keys\x18\x02 \x03(\t\x12@\n\x08services\x18\x03 \x03(\x0b\x32..yandex.cloud.billing.usage_records.v1.Service\x12\x38\n\x04skus\x18\x04 \x03(\x0b\x32*.yandex.cloud.billing.usage_records.v1.SKU\x12O\n\x10\x62illing_accounts\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.billing.usage_records.v1.BillingAccount\"\x8e\x02\n\x0fGetLabelRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x17\n\tlabel_key\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0blabel_value\x18\x05 \x01(\t\x12\x1a\n\x12label_value_filter\x18\x06 \x03(\t\x12\x11\n\tpage_size\x18\x07 \x01(\x03\x12\x12\n\npage_token\x18\x08 \x01(\t\"]\n\x10GetLabelResponse\x12\x14\n\x0clabel_values\x18\x01 \x03(\t\x12\x1a\n\x12label_value_filter\x18\x02 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\xeb\x01\n\x0fGetCloudRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x11\n\tcloud_ids\x18\x04 \x03(\t\x12\x12\n\nfolder_ids\x18\x05 \x03(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x03\x12\x12\n\npage_token\x18\x07 \x01(\t\"\x88\x02\n\x10GetCloudResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.GetCloudResponse.CloudInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x88\x01\n\tCloudInfo\x12;\n\x05\x63loud\x18\x01 \x01(\x0b\x32,.yandex.cloud.billing.usage_records.v1.Cloud\x12>\n\x07\x66olders\x18\x02 \x03(\x0b\x32-.yandex.cloud.billing.usage_records.v1.Folder\"\xdf\x01\n\x15GetResourceIDsRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x03\x12\x12\n\npage_token\x18\x06 \x01(\t\"G\n\x16GetResourceIDsResponse\x12\x14\n\x0cresource_ids\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x98\x04\n\x0fMetadataService\x12{\n\x08GetUsage\x12\x36.yandex.cloud.billing.usage_records.v1.GetUsageRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetUsageResponse\x12{\n\x08GetLabel\x12\x36.yandex.cloud.billing.usage_records.v1.GetLabelRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetLabelResponse\x12{\n\x08GetCloud\x12\x36.yandex.cloud.billing.usage_records.v1.GetCloudRequest\x1a\x37.yandex.cloud.billing.usage_records.v1.GetCloudResponse\x12\x8d\x01\n\x0eGetResourceIDs\x12<.yandex.cloud.billing.usage_records.v1.GetResourceIDsRequest\x1a=.yandex.cloud.billing.usage_records.v1.GetResourceIDsResponseB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.metadata_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_GETUSAGEREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETUSAGEREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETLABELREQUEST'].fields_by_name['label_key']._loaded_options = None
  _globals['_GETLABELREQUEST'].fields_by_name['label_key']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETCLOUDREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETCLOUDREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_GETRESOURCEIDSREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_GETUSAGEREQUEST']._serialized_start=227
  _globals['_GETUSAGEREQUEST']._serialized_end=384
  _globals['_GETUSAGERESPONSE']._serialized_start=387
  _globals['_GETUSAGERESPONSE']._serialized_end=692
  _globals['_GETLABELREQUEST']._serialized_start=695
  _globals['_GETLABELREQUEST']._serialized_end=965
  _globals['_GETLABELRESPONSE']._serialized_start=967
  _globals['_GETLABELRESPONSE']._serialized_end=1060
  _globals['_GETCLOUDREQUEST']._serialized_start=1063
  _globals['_GETCLOUDREQUEST']._serialized_end=1298
  _globals['_GETCLOUDRESPONSE']._serialized_start=1301
  _globals['_GETCLOUDRESPONSE']._serialized_end=1565
  _globals['_GETCLOUDRESPONSE_CLOUDINFO']._serialized_start=1429
  _globals['_GETCLOUDRESPONSE_CLOUDINFO']._serialized_end=1565
  _globals['_GETRESOURCEIDSREQUEST']._serialized_start=1568
  _globals['_GETRESOURCEIDSREQUEST']._serialized_end=1791
  _globals['_GETRESOURCEIDSRESPONSE']._serialized_start=1793
  _globals['_GETRESOURCEIDSRESPONSE']._serialized_end=1864
  _globals['_METADATASERVICE']._serialized_start=1867
  _globals['_METADATASERVICE']._serialized_end=2403
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.organizationmanager.v1.idp.application.saml.signature_certificate_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSignatureCertificateRequest(google.protobuf.message.Message):
    """Request to get a signature certificate by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate to return."""
    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id"]) -> None: ...

global___GetSignatureCertificateRequest = GetSignatureCertificateRequest

@typing.final
class ListSignatureCertificatesRequest(google.protobuf.message.Message):
    """Request to list signature certificates for a SAML application."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to list certificates for."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSignatureCertificatesRequest = ListSignatureCertificatesRequest

@typing.final
class ListSignatureCertificatesResponse(google.protobuf.message.Message):
    """Response message for [SignatureCertificateService.List]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def signature_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.application.saml.signature_certificate_pb2.SignatureCertificate]:
        """List of signature certificates."""

    def __init__(
        self,
        *,
        signature_certificates: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.application.saml.signature_certificate_pb2.SignatureCertificate] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "signature_certificates", b"signature_certificates"]) -> None: ...

global___ListSignatureCertificatesResponse = ListSignatureCertificatesResponse

@typing.final
class CreateSignatureCertificateRequest(google.protobuf.message.Message):
    """Request to create a new signature certificate."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    """ID of the SAML application to create the certificate for."""
    name: builtins.str
    """Name of the signature certificate.
    The name is unique within the application. 3-63 characters long.
    """
    description: builtins.str
    """Description of the signature certificate. 0-256 characters long."""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "description", b"description", "name", b"name"]) -> None: ...

global___CreateSignatureCertificateRequest = CreateSignatureCertificateRequest

@typing.final
class CreateSignatureCertificateMetadata(google.protobuf.message.Message):
    """Metadata for the [SignatureCertificateService.Create] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate that is being created."""
    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id"]) -> None: ...

global___CreateSignatureCertificateMetadata = CreateSignatureCertificateMetadata

@typing.final
class UpdateSignatureCertificateRequest(google.protobuf.message.Message):
    """Request to update an existing signature certificate."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate to update."""
    name: builtins.str
    """New name for the signature certificate."""
    description: builtins.str
    """New description for the signature certificate."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the certificate are going to be updated."""

    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name", "signature_certificate_id", b"signature_certificate_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSignatureCertificateRequest = UpdateSignatureCertificateRequest

@typing.final
class UpdateSignatureCertificateMetadata(google.protobuf.message.Message):
    """Metadata for the [SignatureCertificateService.Update] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate that is being updated."""
    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id"]) -> None: ...

global___UpdateSignatureCertificateMetadata = UpdateSignatureCertificateMetadata

@typing.final
class DeleteSignatureCertificateRequest(google.protobuf.message.Message):
    """Request to delete a signature certificate."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate to delete."""
    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id"]) -> None: ...

global___DeleteSignatureCertificateRequest = DeleteSignatureCertificateRequest

@typing.final
class DeleteSignatureCertificateMetadata(google.protobuf.message.Message):
    """Metadata for the [SignatureCertificateService.Delete] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    signature_certificate_id: builtins.str
    """ID of the signature certificate that is being deleted."""
    def __init__(
        self,
        *,
        signature_certificate_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["signature_certificate_id", b"signature_certificate_id"]) -> None: ...

global___DeleteSignatureCertificateMetadata = DeleteSignatureCertificateMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnPremiseMongo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    REPLICA_SET_FIELD_NUMBER: builtins.int
    TLS_MODE_FIELD_NUMBER: builtins.int
    port: builtins.int
    """TCP Port number"""
    replica_set: builtins.str
    """Replica set name"""
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Host names of the replica set"""

    @property
    def tls_mode(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode:
        """TLS settings for the server connection. Empty implies plaintext connection"""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        port: builtins.int = ...,
        replica_set: builtins.str = ...,
        tls_mode: yandex.cloud.datatransfer.v1.endpoint.common_pb2.TLSMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tls_mode", b"tls_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "port", b"port", "replica_set", b"replica_set", "tls_mode", b"tls_mode"]) -> None: ...

global___OnPremiseMongo = OnPremiseMongo

@typing.final
class MongoConnectionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    ON_PREMISE_FIELD_NUMBER: builtins.int
    CONNECTION_MANAGER_CONNECTION_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    AUTH_SOURCE_FIELD_NUMBER: builtins.int
    mdb_cluster_id: builtins.str
    """Identifier of the Yandex StoreDoc cluster
    Use one of:  mdb_cluster_id/on_premise/connection_manager_connection
    """
    user: builtins.str
    """User name, required unless connection_manager_connection is used"""
    auth_source: builtins.str
    """Database name associated with the credentials"""
    @property
    def on_premise(self) -> global___OnPremiseMongo:
        """Connection settings of the on-premise MongoDB server
        Use one of:  mdb_cluster_id/on_premise/connection_manager_connection
        """

    @property
    def connection_manager_connection(self) -> global___MongoConnectionManagerConnection:
        """Get StoreDoc/MongoDB installation params and credentials from Connection Manager
        Use one of:  mdb_cluster_id/on_premise/connection_manager_connection
        """

    @property
    def password(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret:
        """Password for user"""

    def __init__(
        self,
        *,
        mdb_cluster_id: builtins.str = ...,
        on_premise: global___OnPremiseMongo | None = ...,
        connection_manager_connection: global___MongoConnectionManagerConnection | None = ...,
        user: builtins.str = ...,
        password: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        auth_source: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["address", b"address", "connection_manager_connection", b"connection_manager_connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "auth_source", b"auth_source", "connection_manager_connection", b"connection_manager_connection", "mdb_cluster_id", b"mdb_cluster_id", "on_premise", b"on_premise", "password", b"password", "user", b"user"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["address", b"address"]) -> typing.Literal["mdb_cluster_id", "on_premise", "connection_manager_connection"] | None: ...

global___MongoConnectionOptions = MongoConnectionOptions

@typing.final
class MongoConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def connection_options(self) -> global___MongoConnectionOptions: ...
    def __init__(
        self,
        *,
        connection_options: global___MongoConnectionOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "connection_options", b"connection_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["connection", b"connection"]) -> typing.Literal["connection_options"] | None: ...

global___MongoConnection = MongoConnection

@typing.final
class MongoCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_NAME_FIELD_NUMBER: builtins.int
    COLLECTION_NAME_FIELD_NUMBER: builtins.int
    database_name: builtins.str
    collection_name: builtins.str
    def __init__(
        self,
        *,
        database_name: builtins.str = ...,
        collection_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["collection_name", b"collection_name", "database_name", b"database_name"]) -> None: ...

global___MongoCollection = MongoCollection

@typing.final
class MongoSource(google.protobuf.message.Message):
    """Settings specific to the MongoDB source endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    COLLECTIONS_FIELD_NUMBER: builtins.int
    EXCLUDED_COLLECTIONS_FIELD_NUMBER: builtins.int
    SECONDARY_PREFERRED_MODE_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """Identifier of the Yandex Cloud VPC subnetwork to user for accessing the
    database. 
    If omitted, the server has to be accessible via Internet
    """
    secondary_preferred_mode: builtins.bool
    """Read mode for mongo client: whether the secondary server should be preferred to
    the primary when copying data
    """
    @property
    def connection(self) -> global___MongoConnection:
        """Connection settings"""

    @property
    def collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoCollection]:
        """List of collections for replication. Empty list implies replication of all
        tables on the deployment. Allowed to use * as collection name.
        """

    @property
    def excluded_collections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MongoCollection]:
        """List of forbidden collections for replication. Allowed to use * as collection
        name for forbid all collections of concrete schema.
        """

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of security groups that the transfer associated with this endpoint should
        use
        """

    def __init__(
        self,
        *,
        connection: global___MongoConnection | None = ...,
        subnet_id: builtins.str = ...,
        collections: collections.abc.Iterable[global___MongoCollection] | None = ...,
        excluded_collections: collections.abc.Iterable[global___MongoCollection] | None = ...,
        secondary_preferred_mode: builtins.bool = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["collections", b"collections", "connection", b"connection", "excluded_collections", b"excluded_collections", "secondary_preferred_mode", b"secondary_preferred_mode", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MongoSource = MongoSource

@typing.final
class MongoTarget(google.protobuf.message.Message):
    """Settings specific to the MongoDB target endpoint"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database name. If not empty, then all the data will be written to the database
    with the specified name; otherwise the database name is the same as in the
    source endpoint
    """
    cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType
    """How to clean collections when activating the transfer. One of `DISABLED`, `DROP`
    or `TRUNCATE`
    """
    subnet_id: builtins.str
    """Identifier of the Yandex Cloud VPC subnetwork to user for accessing the
    database. 
    If omitted, the server has to be accessible via Internet
    """
    @property
    def connection(self) -> global___MongoConnection:
        """Connection settings"""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of security groups that the transfer associated with this endpoint should
        use
        """

    def __init__(
        self,
        *,
        connection: global___MongoConnection | None = ...,
        database: builtins.str = ...,
        cleanup_policy: yandex.cloud.datatransfer.v1.endpoint.common_pb2.CleanupPolicy.ValueType = ...,
        subnet_id: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "connection", b"connection", "database", b"database", "security_groups", b"security_groups", "subnet_id", b"subnet_id"]) -> None: ...

global___MongoTarget = MongoTarget

@typing.final
class MongoConnectionManagerConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    REPLICA_SET_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of connectionmanager connection with mongodb/Yandex Storedoc installation
    parameters and credentials
    """
    replica_set: builtins.str
    """Replica set name, used only for on-premise mongodb installations"""
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        replica_set: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "replica_set", b"replica_set"]) -> None: ...

global___MongoConnectionManagerConnection = MongoConnectionManagerConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.mcpgateway.v1 import mcp_gateway_pb2 as yandex_dot_cloud_dot_serverless_dot_mcpgateway_dot_v1_dot_mcp__gateway__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/serverless/mcpgateway/v1/mcp_gateway_service.proto\x12%yandex.cloud.serverless.mcpgateway.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x37yandex/cloud/serverless/mcpgateway/v1/mcp_gateway.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"4\n\x14GetMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"g\n\x15ListMcpGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"}\n\x16ListMcpGatewayResponse\x12J\n\x08gateways\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.serverless.mcpgateway.v1.McpGatewayPreview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xad\x04\n\x17\x43reateMcpGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12?\n\x04name\x18\x02 \x01(\tB1\xe8\xc7\x31\x01\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x05<=128\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.mcpgateway.v1.CreateMcpGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12=\n\x05tools\x18\x05 \x03(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpTool\x12\x46\n\x0blog_options\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12\x0e\n\x06public\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x18\x43reateMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xdf\x04\n\x17UpdateMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12;\n\x04name\x18\x02 \x01(\tB-\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x05<=128\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tB\x0b\x8a\xc8\x31\x07<=65536\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.mcpgateway.v1.UpdateMcpGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12=\n\x05tools\x18\x05 \x03(\x0b\x32..yandex.cloud.serverless.mcpgateway.v1.McpTool\x12\x46\n\x0blog_options\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.serverless.mcpgateway.v1.LogOptions\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\x12/\n\x0bupdate_mask\x18\t \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0e\n\x06public\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x18UpdateMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"7\n\x17\x44\x65leteMcpGatewayRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"8\n\x18\x44\x65leteMcpGatewayMetadata\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8f\x01\n\x15ListOperationsRequest\x12\x1c\n\x0emcp_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xc4\x0e\n\x11McpGatewayService\x12\xaa\x01\n\x03Get\x12;.yandex.cloud.serverless.mcpgateway.v1.GetMcpGatewayRequest\x1a\x31.yandex.cloud.serverless.mcpgateway.v1.McpGateway\"3\x82\xd3\xe4\x93\x02-\x12+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}\x12\xa7\x01\n\x04List\x12<.yandex.cloud.serverless.mcpgateway.v1.ListMcpGatewayRequest\x1a=.yandex.cloud.serverless.mcpgateway.v1.ListMcpGatewayResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/mcpgateway/v1/mcpGateways\x12\xbc\x01\n\x06\x43reate\x12>.yandex.cloud.serverless.mcpgateway.v1.CreateMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*&\n\x18\x43reateMcpGatewayMetadata\x12\nMcpGateway\x82\xd3\xe4\x93\x02\x1f\"\x1a/mcpgateway/v1/mcpGateways:\x01*\x12\xcd\x01\n\x06Update\x12>.yandex.cloud.serverless.mcpgateway.v1.UpdateMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*&\n\x18UpdateMcpGatewayMetadata\x12\nMcpGateway\x82\xd3\xe4\x93\x02\x30\x32+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12>.yandex.cloud.serverless.mcpgateway.v1.DeleteMcpGatewayRequest\x1a!.yandex.cloud.operation.Operation\"h\xb2\xd2*1\n\x18\x44\x65leteMcpGatewayMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}\x12\xcd\x01\n\x0eListOperations\x12<.yandex.cloud.serverless.mcpgateway.v1.ListOperationsRequest\x1a=.yandex.cloud.serverless.mcpgateway.v1.ListOperationsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/mcpgateway/v1/mcpGateways/{mcp_gateway_id}/operations\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/mcpgateway/v1/mcpGateways/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/mcpgateway/v1/mcpGateways/{resource_id}:setAccessBindings:\x01*\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\x32=/mcpgateway/v1/mcpGateways/{resource_id}:updateAccessBindings:\x01*B\x81\x01\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.mcpgateway.v1.mcp_gateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.serverless.mcpgateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mcpgateway/v1;mcpgateway'
  _globals['_GETMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_GETMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTMCPGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTMCPGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\005<=128'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\007<=65536'
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEMCPGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\005<=128'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\007<=65536'
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._loaded_options = None
  _globals['_UPDATEMCPGATEWAYMETADATA'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_DELETEMCPGATEWAYREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_DELETEMCPGATEWAYMETADATA'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['mcp_gateway_id']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['mcp_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/mcpgateway/v1/mcpGateways'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateMcpGatewayMetadata\022\nMcpGateway\202\323\344\223\002\037\"\032/mcpgateway/v1/mcpGateways:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateMcpGatewayMetadata\022\nMcpGateway\202\323\344\223\00202+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteMcpGatewayMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/mcpgateway/v1/mcpGateways/{mcp_gateway_id}'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0028\0226/mcpgateway/v1/mcpGateways/{mcp_gateway_id}/operations'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002=\022;/mcpgateway/v1/mcpGateways/{resource_id}:listAccessBindings'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/mcpgateway/v1/mcpGateways/{resource_id}:setAccessBindings:\001*'
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_MCPGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B2=/mcpgateway/v1/mcpGateways/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETMCPGATEWAYREQUEST']._serialized_start=366
  _globals['_GETMCPGATEWAYREQUEST']._serialized_end=418
  _globals['_LISTMCPGATEWAYREQUEST']._serialized_start=420
  _globals['_LISTMCPGATEWAYREQUEST']._serialized_end=523
  _globals['_LISTMCPGATEWAYRESPONSE']._serialized_start=525
  _globals['_LISTMCPGATEWAYRESPONSE']._serialized_end=650
  _globals['_CREATEMCPGATEWAYREQUEST']._serialized_start=653
  _globals['_CREATEMCPGATEWAYREQUEST']._serialized_end=1210
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_CREATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_CREATEMCPGATEWAYMETADATA']._serialized_start=1212
  _globals['_CREATEMCPGATEWAYMETADATA']._serialized_end=1293
  _globals['_UPDATEMCPGATEWAYREQUEST']._serialized_start=1296
  _globals['_UPDATEMCPGATEWAYREQUEST']._serialized_end=1903
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_UPDATEMCPGATEWAYREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_UPDATEMCPGATEWAYMETADATA']._serialized_start=1905
  _globals['_UPDATEMCPGATEWAYMETADATA']._serialized_end=1986
  _globals['_DELETEMCPGATEWAYREQUEST']._serialized_start=1988
  _globals['_DELETEMCPGATEWAYREQUEST']._serialized_end=2043
  _globals['_DELETEMCPGATEWAYMETADATA']._serialized_start=2045
  _globals['_DELETEMCPGATEWAYMETADATA']._serialized_end=2101
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2104
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2247
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2249
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2353
  _globals['_MCPGATEWAYSERVICE']._serialized_start=2356
  _globals['_MCPGATEWAYSERVICE']._serialized_end=4216
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.billing.usage_records.v1.common_types_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreditDetails(google.protobuf.message.Message):
    """Detailed breakdown of credits (discounts, incentives, grants, etc.) applied to an entity.
    Credits reduce the effective cost that customers pay for cloud resources.
    The 'credit' field is the total amount of credits (the sum of all credit types below).
    This breakdown allows for detailed analysis of different discount types affecting billing.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDIT_FIELD_NUMBER: builtins.int
    MONETARY_GRANT_CREDIT_FIELD_NUMBER: builtins.int
    VOLUME_INCENTIVE_CREDIT_FIELD_NUMBER: builtins.int
    CUD_CREDIT_FIELD_NUMBER: builtins.int
    FREE_CREDIT_FIELD_NUMBER: builtins.int
    @property
    def credit(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Total amount of credits (sum of all credit types) applied to the entity.
        This is the overall discount applied, reducing the cost to arrive at the final expense.
        Formula: expense = cost + credit
        """

    @property
    def monetary_grant_credit(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Credits granted as a one-time monetary grant."""

    @property
    def volume_incentive_credit(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Credits given as a volume-based incentive."""

    @property
    def cud_credit(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Committed Use Discount credits."""

    @property
    def free_credit(self) -> yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal:
        """Credits provided as part of a 'free' program."""

    def __init__(
        self,
        *,
        credit: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        monetary_grant_credit: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        volume_incentive_credit: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        cud_credit: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
        free_credit: yandex.cloud.billing.usage_records.v1.common_types_pb2.StringDecimal | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["credit", b"credit", "cud_credit", b"cud_credit", "free_credit", b"free_credit", "monetary_grant_credit", b"monetary_grant_credit", "volume_incentive_credit", b"volume_incentive_credit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["credit", b"credit", "cud_credit", b"cud_credit", "free_credit", b"free_credit", "monetary_grant_credit", b"monetary_grant_credit", "volume_incentive_credit", b"volume_incentive_credit"]) -> None: ...

global___CreditDetails = CreditDetails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/marketplace/stacklandlicenseapi/v1/license_server.proto\x12/yandex.cloud.marketplace.stacklandlicenseapi.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xaa\x01\n\x15LicenseServerMetadata\x12\x62\n\x06labels\x18\x01 \x03(\x0b\x32R.yandex.cloud.marketplace.stacklandlicenseapi.v1.LicenseServerMetadata.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x0fRegisterRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x12\x62illing_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12X\n\x08metadata\x18\x03 \x01(\x0b\x32\x46.yandex.cloud.marketplace.stacklandlicenseapi.v1.LicenseServerMetadata\"\x86\x01\n\rLicenseServer\x12\x11\n\tserver_id\x18\x01 \x01(\t\x12\x19\n\x11ls_ca_certificate\x18\x02 \x01(\t\x12\x16\n\x0els_private_key\x18\x03 \x01(\t\x12/\n\x0bvalid_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"T\n\x1dRegisterLicenseServerMetadata\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\x12\x1a\n\x12\x62illing_account_id\x18\x02 \x01(\tB\x9e\x01\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.stacklandlicenseapi.v1.license_server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapi'
  _globals['_LICENSESERVERMETADATA_LABELSENTRY']._loaded_options = None
  _globals['_LICENSESERVERMETADATA_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REGISTERREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_REGISTERREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LICENSESERVERMETADATA']._serialized_start=186
  _globals['_LICENSESERVERMETADATA']._serialized_end=356
  _globals['_LICENSESERVERMETADATA_LABELSENTRY']._serialized_start=311
  _globals['_LICENSESERVERMETADATA_LABELSENTRY']._serialized_end=356
  _globals['_REGISTERREQUEST']._serialized_start=359
  _globals['_REGISTERREQUEST']._serialized_end=547
  _globals['_LICENSESERVER']._serialized_start=550
  _globals['_LICENSESERVER']._serialized_end=684
  _globals['_REGISTERLICENSESERVERMETADATA']._serialized_start=686
  _globals['_REGISTERLICENSESERVERMETADATA']._serialized_end=770
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.mdb.mysql.v1.deletion_protection_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Database(google.protobuf.message.Message):
    """An object that represents MySQL database.

    See [the documentation](/docs/managed-mysql/operations/databases) for details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_MODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    cluster_id: builtins.str
    """ID of the cluster that the database belongs to."""
    deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType
    """Deletion Protection inhibits deletion of the database

    Default value: `DELETION_PROTECTION_MODE_DISABLED` (protection is disabled)
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "deletion_protection_mode", b"deletion_protection_mode", "name", b"name"]) -> None: ...

global___Database = Database

@typing.final
class DatabaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_MODE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the database."""
    deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType
    """Deletion Protection inhibits deletion of the database

    Default value: `DELETION_PROTECTION_MODE_DISABLED` (protection is disabled)
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        deletion_protection_mode: yandex.cloud.mdb.mysql.v1.deletion_protection_pb2.DeletionProtectionMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection_mode", b"deletion_protection_mode", "name", b"name"]) -> None: ...

global___DatabaseSpec = DatabaseSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/dns/v1/dns_firewall.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/dns/v1/dns_firewall.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/dns/v1/dns_firewall.proto\x12\x13yandex.cloud.dns.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x05\n\x0b\x44nsFirewall\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12<\n\x06labels\x18\x06 \x03(\x0b\x32,.yandex.cloud.dns.v1.DnsFirewall.LabelsEntry\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x08 \x01(\x08\x12H\n\x0fresource_config\x18\t \x01(\x0b\x32/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig\x12/\n\x0fwhitelist_fqdns\x18\n \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x12/\n\x0f\x62lacklist_fqdns\x18\x0b \x03(\tB\x16\x82\xc8\x31\x05<=255\x8a\xc8\x31\x05<=255\x90\xc8\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xfc\x01\n\x0eResourceConfig\x12J\n\x04type\x18\x01 \x01(\x0e\x32<.yandex.cloud.dns.v1.DnsFirewall.ResourceConfig.ResourceType\x12+\n\x0cresource_ids\x18\x02 \x03(\tB\x15\x82\xc8\x31\x05\x30-100\x8a\xc8\x31\x04<=64\x90\xc8\x31\x01\x12\x1e\n\x16locking_policy_enabled\x18\x03 \x01(\x08\"Q\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07NETWORK\x10\x01\x12\n\n\x06\x46OLDER\x10\x02\x12\t\n\x05\x43LOUD\x10\x03\x42V\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dns.v1.dns_firewall_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns'
  _globals['_DNSFIREWALL_LABELSENTRY']._loaded_options = None
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DNSFIREWALL_RESOURCECONFIG'].fields_by_name['resource_ids']._loaded_options = None
  _globals['_DNSFIREWALL_RESOURCECONFIG'].fields_by_name['resource_ids']._serialized_options = b'\202\3101\0050-100\212\3101\004<=64\220\3101\001'
  _globals['_DNSFIREWALL'].fields_by_name['whitelist_fqdns']._loaded_options = None
  _globals['_DNSFIREWALL'].fields_by_name['whitelist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_DNSFIREWALL'].fields_by_name['blacklist_fqdns']._loaded_options = None
  _globals['_DNSFIREWALL'].fields_by_name['blacklist_fqdns']._serialized_options = b'\202\3101\005<=255\212\3101\005<=255\220\3101\001'
  _globals['_DNSFIREWALL']._serialized_start=128
  _globals['_DNSFIREWALL']._serialized_end=837
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_start=537
  _globals['_DNSFIREWALL_LABELSENTRY']._serialized_end=582
  _globals['_DNSFIREWALL_RESOURCECONFIG']._serialized_start=585
  _globals['_DNSFIREWALL_RESOURCECONFIG']._serialized_end=837
  _globals['_DNSFIREWALL_RESOURCECONFIG_RESOURCETYPE']._serialized_start=756
  _globals['_DNSFIREWALL_RESOURCECONFIG_RESOURCETYPE']._serialized_end=837
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/mfa_enforcement_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/mfa_enforcement_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import mfa_enforcement_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_mfa__enforcement__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAyandex/cloud/organizationmanager/v1/mfa_enforcement_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a\x39yandex/cloud/organizationmanager/v1/mfa_enforcement.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x81\x04\n\x1b\x43reateMfaEnforcementRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06\x61\x63r_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x37\n\x03ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xe8\xc7\x31\x01\xfa\xc7\x31\x07<=8760h\x12]\n\x06status\x18\x04 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.CreateMfaEnforcementRequest.StatusB\x04\xe8\xc7\x31\x01\x12,\n\x08\x61pply_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\renroll_window\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x35\n\x04name\x18\x07 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=256\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x11\n\rSTATUS_ACTIVE\x10\x01\x12\x13\n\x0fSTATUS_INACTIVE\x10\x02\"S\n\x1c\x43reateMfaEnforcementMetadata\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x1a\n\x12mfa_enforcement_id\x18\x03 \x01(\t\"\x9e\x04\n\x1bUpdateMfaEnforcementRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x06\x61\x63r_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x33\n\x03ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07<=8760h\x12W\n\x06status\x18\x04 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.UpdateMfaEnforcementRequest.Status\x12,\n\x08\x61pply_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\renroll_window\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0bupdate_mask\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x08 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\t \x01(\tB\t\x8a\xc8\x31\x05<=256\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x11\n\rSTATUS_ACTIVE\x10\x01\x12\x13\n\x0fSTATUS_INACTIVE\x10\x02\":\n\x1cUpdateMfaEnforcementMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"I\n\x1d\x41\x63tivateMfaEnforcementRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1e\x41\x63tivateMfaEnforcementMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"K\n\x1f\x44\x65\x61\x63tivateMfaEnforcementRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\">\n DeactivateMfaEnforcementMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"G\n\x1b\x44\x65leteMfaEnforcementRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x1c\x44\x65leteMfaEnforcementMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"D\n\x18GetMfaEnforcementRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x82\x01\n\x1aListMfaEnforcementsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x85\x01\n\x1bListMfaEnforcementsResponse\x12M\n\x10mfa_enforcements\x18\x01 \x03(\x0b\x32\x33.yandex.cloud.organizationmanager.v1.MfaEnforcement\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9a\x01\n\x15UpdateAudienceRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0f\x61udience_deltas\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.organizationmanager.v1.AudienceDeltaB\n\x82\xc8\x31\x06\x31-1000\"\x90\x01\n\x16UpdateAudienceResponse\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x10\x65\x66\x66\x65\x63tive_deltas\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.organizationmanager.v1.AudienceDelta\"\xc8\x01\n\rAudienceDelta\x12O\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.organizationmanager.v1.AudienceDelta.ActionB\x04\xe8\xc7\x31\x01\x12!\n\nsubject_id\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"C\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x0e\n\nACTION_ADD\x10\x01\x12\x11\n\rACTION_REMOVE\x10\x02\"4\n\x16UpdateAudienceMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"~\n\x13ListAudienceRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xa9\x01\n\x14ListAudienceResponse\x12S\n\x08subjects\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.organizationmanager.v1.ListAudienceResponse.Subject\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a#\n\x07Subject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xa2\x01\n\x1dUpdateExcludedAudienceRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0f\x61udience_deltas\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.organizationmanager.v1.AudienceDeltaB\n\x82\xc8\x31\x06\x31-1000\"\x98\x01\n\x1eUpdateExcludedAudienceResponse\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x10\x65\x66\x66\x65\x63tive_deltas\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.organizationmanager.v1.AudienceDelta\"<\n\x1eUpdateExcludedAudienceMetadata\x12\x1a\n\x12mfa_enforcement_id\x18\x02 \x01(\t\"\x86\x01\n\x1bListExcludedAudienceRequest\x12(\n\x12mfa_enforcement_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xb9\x01\n\x1cListExcludedAudienceResponse\x12[\n\x08subjects\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.ListExcludedAudienceResponse.Subject\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a#\n\x07Subject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t2\xc1\x14\n\x15MfaEnforcementService\x12\xd4\x01\n\x06\x43reate\x12@.yandex.cloud.organizationmanager.v1.CreateMfaEnforcementRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*.\n\x1c\x43reateMfaEnforcementMetadata\x12\x0eMfaEnforcement\x82\xd3\xe4\x93\x02-\"(/organization-manager/v1/mfaEnforcements:\x01*\x12\xe9\x01\n\x06Update\x12@.yandex.cloud.organizationmanager.v1.UpdateMfaEnforcementRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*.\n\x1cUpdateMfaEnforcementMetadata\x12\x0eMfaEnforcement\x82\xd3\xe4\x93\x02\x42\x32=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:\x01*\x12\xf6\x01\n\x08\x41\x63tivate\x12\x42.yandex.cloud.organizationmanager.v1.ActivateMfaEnforcementRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*0\n\x1e\x41\x63tivateMfaEnforcementMetadata\x12\x0eMfaEnforcement\x82\xd3\xe4\x93\x02H2F/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:activate\x12\xfe\x01\n\nDeactivate\x12\x44.yandex.cloud.organizationmanager.v1.DeactivateMfaEnforcementRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*2\n DeactivateMfaEnforcementMetadata\x12\x0eMfaEnforcement\x82\xd3\xe4\x93\x02J2H/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:deactivate\x12\xed\x01\n\x06\x44\x65lete\x12@.yandex.cloud.organizationmanager.v1.DeleteMfaEnforcementRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*5\n\x1c\x44\x65leteMfaEnforcementMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}\x12\xc0\x01\n\x03Get\x12=.yandex.cloud.organizationmanager.v1.GetMfaEnforcementRequest\x1a\x33.yandex.cloud.organizationmanager.v1.MfaEnforcement\"E\x82\xd3\xe4\x93\x02?\x12=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}\x12\xbb\x01\n\x04List\x12?.yandex.cloud.organizationmanager.v1.ListMfaEnforcementsRequest\x1a@.yandex.cloud.organizationmanager.v1.ListMfaEnforcementsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/organization-manager/v1/mfaEnforcements\x12\xfd\x01\n\x0eUpdateAudience\x12:.yandex.cloud.organizationmanager.v1.UpdateAudienceRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*0\n\x16UpdateAudienceMetadata\x12\x16UpdateAudienceResponse\x82\xd3\xe4\x93\x02Q2L/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:updateAudience:\x01*\x12\xd7\x01\n\x0cListAudience\x12\x38.yandex.cloud.organizationmanager.v1.ListAudienceRequest\x1a\x39.yandex.cloud.organizationmanager.v1.ListAudienceResponse\"R\x82\xd3\xe4\x93\x02L\x12J/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:listAudience\x12\xa5\x02\n\x16UpdateExcludedAudience\x12\x42.yandex.cloud.organizationmanager.v1.UpdateExcludedAudienceRequest\x1a!.yandex.cloud.operation.Operation\"\xa3\x01\xb2\xd2*@\n\x1eUpdateExcludedAudienceMetadata\x12\x1eUpdateExcludedAudienceResponse\x82\xd3\xe4\x93\x02Y2T/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:updateExcludedAudience:\x01*\x12\xf7\x01\n\x14ListExcludedAudience\x12@.yandex.cloud.organizationmanager.v1.ListExcludedAudienceRequest\x1a\x41.yandex.cloud.organizationmanager.v1.ListExcludedAudienceResponse\"Z\x82\xd3\xe4\x93\x02T\x12R/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:listExcludedAudienceB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['acr_id']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['acr_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['ttl']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['ttl']._serialized_options = b'\350\3071\001\372\3071\007<=8760h'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['enroll_window']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['enroll_window']._serialized_options = b'\350\3071\001'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEMFAENFORCEMENTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['acr_id']._loaded_options = None
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['acr_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['ttl']._loaded_options = None
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['ttl']._serialized_options = b'\372\3071\007<=8760h'
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEMFAENFORCEMENTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_ACTIVATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_ACTIVATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_DEACTIVATEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_DELETEMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_GETMFAENFORCEMENTREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMFAENFORCEMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_UPDATEAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_UPDATEAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUDIENCEREQUEST'].fields_by_name['audience_deltas']._loaded_options = None
  _globals['_UPDATEAUDIENCEREQUEST'].fields_by_name['audience_deltas']._serialized_options = b'\202\3101\0061-1000'
  _globals['_UPDATEAUDIENCERESPONSE'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_UPDATEAUDIENCERESPONSE'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_AUDIENCEDELTA'].fields_by_name['action']._loaded_options = None
  _globals['_AUDIENCEDELTA'].fields_by_name['action']._serialized_options = b'\350\3071\001'
  _globals['_AUDIENCEDELTA'].fields_by_name['subject_id']._loaded_options = None
  _globals['_AUDIENCEDELTA'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAUDIENCEREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST'].fields_by_name['audience_deltas']._loaded_options = None
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST'].fields_by_name['audience_deltas']._serialized_options = b'\202\3101\0061-1000'
  _globals['_UPDATEEXCLUDEDAUDIENCERESPONSE'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_UPDATEEXCLUDEDAUDIENCERESPONSE'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._loaded_options = None
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['mfa_enforcement_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*.\n\034CreateMfaEnforcementMetadata\022\016MfaEnforcement\202\323\344\223\002-\"(/organization-manager/v1/mfaEnforcements:\001*'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*.\n\034UpdateMfaEnforcementMetadata\022\016MfaEnforcement\202\323\344\223\002B2=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:\001*'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*0\n\036ActivateMfaEnforcementMetadata\022\016MfaEnforcement\202\323\344\223\002H2F/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:activate'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Deactivate']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Deactivate']._serialized_options = b'\262\322*2\n DeactivateMfaEnforcementMetadata\022\016MfaEnforcement\202\323\344\223\002J2H/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:deactivate'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*5\n\034DeleteMfaEnforcementMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002?\022=/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002*\022(/organization-manager/v1/mfaEnforcements'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['UpdateAudience']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['UpdateAudience']._serialized_options = b'\262\322*0\n\026UpdateAudienceMetadata\022\026UpdateAudienceResponse\202\323\344\223\002Q2L/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:updateAudience:\001*'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['ListAudience']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['ListAudience']._serialized_options = b'\202\323\344\223\002L\022J/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:listAudience'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['UpdateExcludedAudience']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['UpdateExcludedAudience']._serialized_options = b'\262\322*@\n\036UpdateExcludedAudienceMetadata\022\036UpdateExcludedAudienceResponse\202\323\344\223\002Y2T/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:updateExcludedAudience:\001*'
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['ListExcludedAudience']._loaded_options = None
  _globals['_MFAENFORCEMENTSERVICE'].methods_by_name['ListExcludedAudience']._serialized_options = b'\202\323\344\223\002T\022R/organization-manager/v1/mfaEnforcements/{mfa_enforcement_id}:listExcludedAudience'
  _globals['_CREATEMFAENFORCEMENTREQUEST']._serialized_start=400
  _globals['_CREATEMFAENFORCEMENTREQUEST']._serialized_end=913
  _globals['_CREATEMFAENFORCEMENTREQUEST_STATUS']._serialized_start=841
  _globals['_CREATEMFAENFORCEMENTREQUEST_STATUS']._serialized_end=913
  _globals['_CREATEMFAENFORCEMENTMETADATA']._serialized_start=915
  _globals['_CREATEMFAENFORCEMENTMETADATA']._serialized_end=998
  _globals['_UPDATEMFAENFORCEMENTREQUEST']._serialized_start=1001
  _globals['_UPDATEMFAENFORCEMENTREQUEST']._serialized_end=1543
  _globals['_UPDATEMFAENFORCEMENTREQUEST_STATUS']._serialized_start=841
  _globals['_UPDATEMFAENFORCEMENTREQUEST_STATUS']._serialized_end=913
  _globals['_UPDATEMFAENFORCEMENTMETADATA']._serialized_start=1545
  _globals['_UPDATEMFAENFORCEMENTMETADATA']._serialized_end=1603
  _globals['_ACTIVATEMFAENFORCEMENTREQUEST']._serialized_start=1605
  _globals['_ACTIVATEMFAENFORCEMENTREQUEST']._serialized_end=1678
  _globals['_ACTIVATEMFAENFORCEMENTMETADATA']._serialized_start=1680
  _globals['_ACTIVATEMFAENFORCEMENTMETADATA']._serialized_end=1740
  _globals['_DEACTIVATEMFAENFORCEMENTREQUEST']._serialized_start=1742
  _globals['_DEACTIVATEMFAENFORCEMENTREQUEST']._serialized_end=1817
  _globals['_DEACTIVATEMFAENFORCEMENTMETADATA']._serialized_start=1819
  _globals['_DEACTIVATEMFAENFORCEMENTMETADATA']._serialized_end=1881
  _globals['_DELETEMFAENFORCEMENTREQUEST']._serialized_start=1883
  _globals['_DELETEMFAENFORCEMENTREQUEST']._serialized_end=1954
  _globals['_DELETEMFAENFORCEMENTMETADATA']._serialized_start=1956
  _globals['_DELETEMFAENFORCEMENTMETADATA']._serialized_end=2014
  _globals['_GETMFAENFORCEMENTREQUEST']._serialized_start=2016
  _globals['_GETMFAENFORCEMENTREQUEST']._serialized_end=2084
  _globals['_LISTMFAENFORCEMENTSREQUEST']._serialized_start=2087
  _globals['_LISTMFAENFORCEMENTSREQUEST']._serialized_end=2217
  _globals['_LISTMFAENFORCEMENTSRESPONSE']._serialized_start=2220
  _globals['_LISTMFAENFORCEMENTSRESPONSE']._serialized_end=2353
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_start=2356
  _globals['_UPDATEAUDIENCEREQUEST']._serialized_end=2510
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_start=2513
  _globals['_UPDATEAUDIENCERESPONSE']._serialized_end=2657
  _globals['_AUDIENCEDELTA']._serialized_start=2660
  _globals['_AUDIENCEDELTA']._serialized_end=2860
  _globals['_AUDIENCEDELTA_ACTION']._serialized_start=2793
  _globals['_AUDIENCEDELTA_ACTION']._serialized_end=2860
  _globals['_UPDATEAUDIENCEMETADATA']._serialized_start=2862
  _globals['_UPDATEAUDIENCEMETADATA']._serialized_end=2914
  _globals['_LISTAUDIENCEREQUEST']._serialized_start=2916
  _globals['_LISTAUDIENCEREQUEST']._serialized_end=3042
  _globals['_LISTAUDIENCERESPONSE']._serialized_start=3045
  _globals['_LISTAUDIENCERESPONSE']._serialized_end=3214
  _globals['_LISTAUDIENCERESPONSE_SUBJECT']._serialized_start=3179
  _globals['_LISTAUDIENCERESPONSE_SUBJECT']._serialized_end=3214
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST']._serialized_start=3217
  _globals['_UPDATEEXCLUDEDAUDIENCEREQUEST']._serialized_end=3379
  _globals['_UPDATEEXCLUDEDAUDIENCERESPONSE']._serialized_start=3382
  _globals['_UPDATEEXCLUDEDAUDIENCERESPONSE']._serialized_end=3534
  _globals['_UPDATEEXCLUDEDAUDIENCEMETADATA']._serialized_start=3536
  _globals['_UPDATEEXCLUDEDAUDIENCEMETADATA']._serialized_end=3596
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST']._serialized_start=3599
  _globals['_LISTEXCLUDEDAUDIENCEREQUEST']._serialized_end=3733
  _globals['_LISTEXCLUDEDAUDIENCERESPONSE']._serialized_start=3736
  _globals['_LISTEXCLUDEDAUDIENCERESPONSE']._serialized_end=3921
  _globals['_LISTEXCLUDEDAUDIENCERESPONSE_SUBJECT']._serialized_start=3179
  _globals['_LISTEXCLUDEDAUDIENCERESPONSE_SUBJECT']._serialized_end=3214
  _globals['_MFAENFORCEMENTSERVICE']._serialized_start=3924
  _globals['_MFAENFORCEMENTSERVICE']._serialized_end=6549
# @@protoc_insertion_point(module_scope)
